{ config, pkgs, lib, ... }:

{
  imports = [
    ../../home/core.nix
    ../../home/i3
  ];

  programs.git = {
    userName = "Laurent Le Houerou";
    userEmail = "laurent@lehouerou.net";
  };

  services.picom = {
    enable = true;
  };

  home.packages = with pkgs; [
    btop
    code-cursor
    lazygit
    neovim
    brave
    
  ];

  programs.kitty = lib.mkForce {
    enable = true;
    settings = {
      font_family = "FiraCode Nerd Font Mono";
      bold_font = "auto";
      italic_font = "auto";
      bold_italic_font = "auto";
      font_size = "12.0";
      confirm_os_window_close = 0;
      # Colors
      foreground = "#CDD6F4";
      background = "#1E1E2E";
      selection_foreground = "#1E1E2E";
      selection_background = "#F5E0DC";
      cursor = "#F5E0DC";
      cursor_text_color = "#1E1E2E";
      url_color = "#F5E0DC";
      active_border_color = "#B4BEFE";
      inactive_border_color = "#6C7086";
      bell_border_color = "#F9E2AF";
      wayland_titlebar_color = "system";
      macos_titlebar_color = "system";
      active_tab_foreground = "#11111B";
      active_tab_background = "#CBA6F7";
      inactive_tab_foreground = "#CDD6F4";
      inactive_tab_background = "#181825";
      tab_bar_background = "#11111B";
      mark1_foreground = "#1E1E2E";
      mark1_background = "#B4BEFE";
      mark2_foreground = "#1E1E2E";
      mark2_background = "#CBA6F7";
      mark3_foreground = "#1E1E2E";
      mark3_background = "#74C7EC";
      color0 = "#45475A";
      color8 = "#585B70";
      color1 = "#F38BA8";
      color9 = "#F38BA8";
      color2 = "#A6E3A1";
      color10 = "#A6E3A1";
      color3 = "#F9E2AF";
      color11 = "#F9E2AF";
      color4 = "#89B4FA";
      color12 = "#89B4FA";
      color5 = "#F5C2E7";
      color13 = "#F5C2E7";
      color6 = "#94E2D5";
      color14 = "#94E2D5";
      color7 = "#BAC2DE";
      color15 = "#A6ADC8";
    };  
  };

  programs.zsh = {
    enable = true;
  };

  services.grobi = {
    enable = true;
    rules = [
      {
        name = "VM Setup";
        outputs_connected = [ "Virtual-1" ];
        configure_single = "Virtual-1@2048x1152";
        atomic = true;
      }
      {
        name = "Triple Monitor Setup";
        outputs_connected = [ "DP-0" "DP-2" "DP-1-3" ];
        configure_row = [
          "DP-2"
          "DP-0"
          "DP-1-3"
        ];
        atomic = true;
        primary = "DP-0";
        execute_after = [
          "${pkgs.xorg.xrandr}/bin/xrandr --output DP-1-3 --rotate left"
        ];
      }
    ];

    
  };
}
